==> firebase_repository-1.0.48.tar.gz: lib/src/entities/tropa_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class TropaEntity extends Equatable {
  ///Atributos obligatorios:
  final String uuid;
  final String nombre;
  final String categoriaUid;
  final String corralUid;
  final bool activo;
  final bool cerrado;
  final bool pendiente;
  final String potreroUid;
  final String propietario;
  final String dieta;
  final bool caravana;

  ///Atributos autogenerados
  final int cabezas;
  final DateTime fechaAlta;
  final DateTime fechaInicio;
  final double metaKilos;
  final double pesoInicio;
  final double pesoPromedio;

  ///Atributos necesarios por default
  final bool seguir;

//  Si está en "true" el desitno es venta, sino es recría.
  final bool vender;
  final bool cpcAutomatico;
  final double cpc;
  final String idDescarga;
  final DateTime primerDescarga;
  final DateTime ultimaDescarga;
  final DateTime ultimaFechaPesada;
  final double ultimaPesada;
  final DateTime ultimaLectura;
  final double remanente;
  final double incremento;
  final double descargado;
  final double decremento;
  final double gdpv;
  final double materiaSeca;
  final bool subtropa;
  final String tropaOrigen;
  final List<dynamic> subtropasList;

  TropaEntity(
      this.uuid,
      this.nombre,
      this.categoriaUid,
      this.corralUid,
      this.activo,
      this.cerrado,
      this.pendiente,
      this.potreroUid,
      this.propietario,
      this.dieta,
      this.caravana,
      this.cabezas,
      this.fechaAlta,
      this.fechaInicio,
      this.metaKilos,
      this.pesoInicio,
      this.pesoPromedio,
      this.seguir,
      this.vender,
      this.cpcAutomatico,
      this.cpc,
      this.idDescarga,
      this.primerDescarga,
      this.ultimaDescarga,
      this.ultimaFechaPesada,
      this.ultimaPesada,
      this.ultimaLectura,
      this.remanente,
      this.incremento,
      this.descargado,
      this.decremento,
      this.gdpv,
      this.materiaSeca,
      this.subtropa,
      this.tropaOrigen,
      this.subtropasList);

  Map<String, Object> toJson() {
    return {
      'nombre': this.nombre,
      'categoriaUid': this.categoriaUid,
      'corralUid': this.corralUid,
      'activo': this.activo,
      'cerrado': this.cerrado,
      'pendiente': this.pendiente,
      'potreroUid': this.potreroUid,
      'propietario': this.propietario,
      'dieta': this.dieta,
      'cabezas': this.cabezas,
      'fechaAlta': this.fechaAlta,
      'fechaInicio': this.fechaInicio,
      'metaKilos': this.metaKilos,
      'pesoInicio': this.pesoInicio,
      'pesoPromedio': this.pesoPromedio,
      'seguir': this.seguir,
      'vender': this.vender,
      'cpcAutomatico': this.cpcAutomatico,
      'cpc': this.cpc,
      'incremento': this.incremento,
      'decremento': this.decremento,
      'gdpv': this.gdpv,
      'materiaSeca': this.materiaSeca,
      'subtropa': this.subtropa,
      'tropaOrigen': this.tropaOrigen,
      'subtropasList': this.subtropasList,
      'descargado': this.descargado,
      'remanente': this.remanente,
      'ultimaLectura': this.ultimaLectura,
      'ultimaPesada': this.ultimaPesada,
      'ultimaFechaPesada': this.ultimaFechaPesada,
      'ultimaDescarga': this.ultimaDescarga,
      'primerDescarga': this.primerDescarga,
      'idDescarga': this.idDescarga,
    };
  }

  @override
  String toString() {
    return 'TropaEntity{uuid: $uuid, nombre: $nombre, categoriaUid: $categoriaUid, corralUid: $corralUid, activo: $activo, cerrado: $cerrado, pendiente: $pendiente, potreroUid: $potreroUid, propietario: $propietario, dieta: $dieta, caravana: $caravana, cabezas: $cabezas, fechaAlta: $fechaAlta, fechaInicio: $fechaInicio, metaKilos: $metaKilos, pesoInicio: $pesoInicio, pesoPromedio: $pesoPromedio, seguir: $seguir, vender: $vender, cpcAutomatico: $cpcAutomatico, cpc: $cpc, idDescarga: $idDescarga, primerDescarga: $primerDescarga, ultimaDescarga: $ultimaDescarga, ultimaFechaPesada: $ultimaFechaPesada, ultimaPesada: $ultimaPesada, ultimaLectura: $ultimaLectura, remanente: $remanente, incremento: $incremento, descargado: $descargado, decremento: $decremento, gdpv: $gdpv, materiaSeca: $materiaSeca, subtropa: $subtropa, tropaOrigen: $tropaOrigen, subtropasList: $subtropasList}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      super == other &&
          other is TropaEntity &&
          runtimeType == other.runtimeType &&
          uuid == other.uuid &&
          nombre == other.nombre &&
          categoriaUid == other.categoriaUid &&
          corralUid == other.corralUid &&
          activo == other.activo &&
          cerrado == other.cerrado &&
          pendiente == other.pendiente &&
          potreroUid == other.potreroUid &&
          propietario == other.propietario &&
          dieta == other.dieta &&
          caravana == other.caravana &&
          cabezas == other.cabezas &&
          fechaAlta == other.fechaAlta &&
          fechaInicio == other.fechaInicio &&
          metaKilos == other.metaKilos &&
          pesoInicio == other.pesoInicio &&
          pesoPromedio == other.pesoPromedio &&
          seguir == other.seguir &&
          vender == other.vender &&
          cpcAutomatico == other.cpcAutomatico &&
          cpc == other.cpc &&
          idDescarga == other.idDescarga &&
          primerDescarga == other.primerDescarga &&
          ultimaDescarga == other.ultimaDescarga &&
          ultimaFechaPesada == other.ultimaFechaPesada &&
          ultimaPesada == other.ultimaPesada &&
          ultimaLectura == other.ultimaLectura &&
          remanente == other.remanente &&
          incremento == other.incremento &&
          descargado == other.descargado &&
          decremento == other.decremento &&
          gdpv == other.gdpv &&
          materiaSeca == other.materiaSeca &&
          subtropa == other.subtropa &&
          tropaOrigen == other.tropaOrigen &&
          subtropasList == other.subtropasList;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      nombre.hashCode ^
      categoriaUid.hashCode ^
      corralUid.hashCode ^
      activo.hashCode ^
      cerrado.hashCode ^
      pendiente.hashCode ^
      potreroUid.hashCode ^
      propietario.hashCode ^
      dieta.hashCode ^
      caravana.hashCode ^
      cabezas.hashCode ^
      fechaAlta.hashCode ^
      fechaInicio.hashCode ^
      metaKilos.hashCode ^
      pesoInicio.hashCode ^
      pesoPromedio.hashCode ^
      seguir.hashCode ^
      vender.hashCode ^
      cpcAutomatico.hashCode ^
      cpc.hashCode ^
      idDescarga.hashCode ^
      primerDescarga.hashCode ^
      ultimaDescarga.hashCode ^
      ultimaFechaPesada.hashCode ^
      ultimaPesada.hashCode ^
      ultimaLectura.hashCode ^
      remanente.hashCode ^
      incremento.hashCode ^
      descargado.hashCode ^
      decremento.hashCode ^
      gdpv.hashCode ^
      materiaSeca.hashCode ^
      subtropa.hashCode ^
      tropaOrigen.hashCode ^
      subtropasList.hashCode;

  TropaEntity.fromJson(Map<String, Object> json)
      : uuid = json['uuid'],
        nombre = json['nombre'],
        categoriaUid = json['categoriaUid'],
        corralUid = json['corralUid'],
        activo = json['activo'],
        cerrado = json['cerrado'],
        pendiente = json['pendiente'],
        potreroUid = json['potreroUid'],
        propietario = json['propietario'],
        dieta = json['dieta'],
        caravana = json['caravana'],
        cabezas = json['cabezas'],
        fechaAlta = json['fechaAlta'],
        fechaInicio = json['fechaInicio'],
        metaKilos = json['metaKilos'],
        pesoInicio = json['pesoInicio'],
        pesoPromedio = json['pesoPromedio'],
        seguir = json['seguir'],
        vender = json['vender'],
        cpcAutomatico = json['cpcAutomatico'],
        cpc = json['cpc'],
        incremento = json['incremento'],
        decremento = json['decremento'],
        gdpv = json['gdpv'],
        materiaSeca = json['materiaSeca'],
        subtropa = json['subtropa'],
        tropaOrigen = json['tropaOrigen'],
        subtropasList = json['subtropasList'],
        idDescarga = json['idDescarga'],
        primerDescarga = json['primerDescarga'],
        ultimaDescarga = json['ultimaDescarga'],
        ultimaFechaPesada = json['ultimaFechaPesada'],
        ultimaPesada = json['ultimaPesada'],
        ultimaLectura = json['ultimaLectura'],
        remanente = json['remanente'],
        descargado = json['descargado'];

  TropaEntity.fromSnapshot(DocumentSnapshot snapshot)
      : uuid = snapshot.documentID,
        nombre = snapshot.data['nombre'],
        cabezas = snapshot.data['cabezas'],
        categoriaUid = snapshot.data['categoria'],
        corralUid = snapshot.data['corral'],
        activo = snapshot.data['activo'],
        cerrado = snapshot.data['cerrado'],
        pendiente = snapshot.data['pendiente'] ?? false,
        potreroUid = snapshot.data['potrero'],
        propietario = snapshot.data['propietario'],
        dieta = snapshot.data['dieta'],
        caravana = snapshot.data['caravana'],
        fechaAlta = snapshot.data['fechaAlta'].toDate(),
        fechaInicio = snapshot.data['fechaInicio'] is Timestamp
            ? snapshot.data['fechaInicio'].toDate()
            : snapshot.data['fechaInicio'],
        metaKilos = snapshot.data['metaKilos'] != null
            ? snapshot.data['metaKilos'].runtimeType == double
                ? snapshot.data['metaKilos']
                : double.parse(snapshot.data['metaKilos'].toString())
            : 0.0,
        pesoInicio = snapshot.data['pesoInicio'],
        pesoPromedio = snapshot.data['pesoPromedio'],
        seguir = snapshot.data['seguir'],
        vender = snapshot.data['vender'],
        cpcAutomatico = snapshot.data['cpcAutomatico'],
        cpc = snapshot.data['cpc'].runtimeType == int
            ? double.parse(snapshot.data['cpc'].toString())
            : snapshot.data['cpc'],
        incremento = double.parse(snapshot.data['incremento'].toString()),
        decremento = double.parse(snapshot.data['decremento'].toString()),
        gdpv = double.parse(snapshot.data['gdpv'].toString()),
        materiaSeca = double.parse(snapshot.data['materiaSeca'].toString()),
        subtropa = snapshot.data['subtropa'] ?? false,
        tropaOrigen = snapshot.data['tropaOrigen'] ?? "",
        subtropasList = snapshot.data['subtropasList'] == null
            ? List<dynamic>()
            : snapshot.data['subtropasList'],
        descargado = snapshot.data['descargado'] is int
            ? double.parse(snapshot.data['descargado'].toString())
            : snapshot.data['descargado'],
        remanente = snapshot.data['remanente'] is int
            ? double.parse(snapshot.data['remanente'].toString())
            : snapshot.data['remanente'],
        ultimaLectura = snapshot.data['ultimaLectura'] != null
            ? snapshot.data['ultimaLectura'].toDate()
            : snapshot.data['fechaAlta'].toDate(),
        ultimaPesada = snapshot.data['ultimaPesada'] != null
            ? double.parse(snapshot.data['ultimaPesada'].toString())
            : snapshot.data['pesoInicio'],
        ultimaFechaPesada = snapshot.data['ultimaFechaPesada'] != null
            ? snapshot.data['ultimaFechaPesada'].toDate()
            : snapshot.data['fechaAlta'].toDate(),
        ultimaDescarga = snapshot.data['ultimaDescarga'] != null
            ? (snapshot.data['ultimaDescarga'] is int ||
                    snapshot.data['ultimaDescarga'] is double)
                ? DateTime.fromMillisecondsSinceEpoch(
                    snapshot.data['ultimaDescarga'].round().toInt())
                : snapshot.data['ultimaDescarga'].toDate()
            : snapshot.data['fechaAlta'].toDate(),
        idDescarga = snapshot.data['idDescarga'],
        primerDescarga = snapshot.data['primerDescarga'] != null
            ? (snapshot.data['primerDescarga'] is int ||
                    snapshot.data['primerDescarga'] is double)
                ? DateTime.fromMillisecondsSinceEpoch(
                    snapshot.data['primerDescarga'].round().toInt())
                : snapshot.data['primerDescarga'].toDate()
            : null;

  Map<String, Object> toDocument() {
    return {
      'activo': this.activo,
      'nombre': this.nombre,
      'categoria': this.categoriaUid,
      'corral': this.corralUid,
      'activo': this.activo,
      'cerrado': this.cerrado,
      'pendiente': this.pendiente,
      'potrero': this.potreroUid,
      'propietario': this.propietario,
      'dieta': this.dieta,
      'caravana': this.caravana,
      'cabezas': this.cabezas,
      'fechaAlta': this.fechaAlta,
      'fechaInicio': this.fechaInicio,
      'metaKilos': this.metaKilos,
      'pesoInicio': this.pesoInicio,
      'pesoPromedio': this.pesoPromedio,
      'seguir': this.seguir,
      'vender': this.vender,
      'cpcAutomatico': this.cpcAutomatico,
      'cpc': this.cpc,
      'incremento': this.incremento,
      'decremento': this.decremento,
      'gdpv': this.gdpv,
      'materiaSeca': this.materiaSeca,
      'subtropa': this.subtropa,
      'tropaOrigen': this.tropaOrigen,
      'subtropasList': this.subtropasList,
      'descargado': this.descargado,
      'remanente': this.remanente,
      'ultimaLectura': this.ultimaLectura,
      'ultimaPesada': this.ultimaPesada,
      'ultimaFechaPesada': this.ultimaFechaPesada,
      'ultimaDescarga': this.ultimaDescarga is DateTime
          ? this.ultimaDescarga.millisecondsSinceEpoch
          : this.ultimaDescarga,
      'idDescarga': this.idDescarga,
      'primerDescarga': this.primerDescarga is DateTime
          ? this.primerDescarga.millisecondsSinceEpoch
          : this.primerDescarga
    };
  }
}

==> firebase_repository-1.0.59.tar.gz: lib/src/entities/tropa_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class TropaEntity extends Equatable {
  ///Atributos obligatorios:
  final String uuid;
  final String nombre;
  final String categoriaUid;
  final String corralUid;
  final bool activo;
  final bool cerrado;
  final bool pendiente;
  final String potreroUid;
  final String propietario;
  final String dieta;
  final bool caravana;

  ///Atributos autogenerados
  final int cabezas;
  final DateTime fechaAlta;
  final DateTime fechaInicio;
  final double metaKilos;
  final double pesoInicio;
  final double pesoPromedio;

  ///Atributos necesarios por default
  final bool seguir;

//  Si está en "true" el desitno es venta, sino es recría.
  final bool vender;
  final bool cpcAutomatico;
  final double cpc;
  final String idDescarga;
  final DateTime primerDescarga;
  final DateTime ultimaDescarga;
  final DateTime ultimaFechaPesada;
  final double ultimaPesada;
  final DateTime ultimaLectura;
  final double remanente;
  final double incremento;
  final double descargado;
  final double decremento;
  final double gdpv;
  final double materiaSeca;
  final bool subtropa;
  final String tropaOrigen;
  final List<dynamic> subtropasList;

  TropaEntity(
      this.uuid,
      this.nombre,
      this.categoriaUid,
      this.corralUid,
      this.activo,
      this.cerrado,
      this.pendiente,
      this.potreroUid,
      this.propietario,
      this.dieta,
      this.caravana,
      this.cabezas,
      this.fechaAlta,
      this.fechaInicio,
      this.metaKilos,
      this.pesoInicio,
      this.pesoPromedio,
      this.seguir,
      this.vender,
      this.cpcAutomatico,
      this.cpc,
      this.idDescarga,
      this.primerDescarga,
      this.ultimaDescarga,
      this.ultimaFechaPesada,
      this.ultimaPesada,
      this.ultimaLectura,
      this.remanente,
      this.incremento,
      this.descargado,
      this.decremento,
      this.gdpv,
      this.materiaSeca,
      this.subtropa,
      this.tropaOrigen,
      this.subtropasList);

  Map<String, Object> toJson() {
    return {
      'nombre': this.nombre,
      'categoriaUid': this.categoriaUid,
      'corralUid': this.corralUid,
      'activo': this.activo,
      'cerrado': this.cerrado,
      'pendiente': this.pendiente,
      'potreroUid': this.potreroUid,
      'propietario': this.propietario,
      'dieta': this.dieta,
      'cabezas': this.cabezas,
      'fechaAlta': this.fechaAlta,
      'fechaInicio': this.fechaInicio,
      'metaKilos': this.metaKilos,
      'pesoInicio': this.pesoInicio,
      'pesoPromedio': this.pesoPromedio,
      'seguir': this.seguir,
      'vender': this.vender,
      'cpcAutomatico': this.cpcAutomatico,
      'cpc': this.cpc,
      'incremento': this.incremento,
      'decremento': this.decremento,
      'gdpv': this.gdpv,
      'materiaSeca': this.materiaSeca,
      'subtropa': this.subtropa,
      'tropaOrigen': this.tropaOrigen,
      'subtropasList': this.subtropasList,
      'descargado': this.descargado,
      'remanente': this.remanente,
      'ultimaLectura': this.ultimaLectura,
      'ultimaPesada': this.ultimaPesada,
      'ultimaFechaPesada': this.ultimaFechaPesada,
      'ultimaDescarga': this.ultimaDescarga,
      'primerDescarga': this.primerDescarga,
      'idDescarga': this.idDescarga,
    };
  }

  @override
  String toString() {
    return 'TropaEntity{uuid: $uuid, nombre: $nombre, categoriaUid: $categoriaUid, corralUid: $corralUid, activo: $activo, cerrado: $cerrado, pendiente: $pendiente, potreroUid: $potreroUid, propietario: $propietario, dieta: $dieta, caravana: $caravana, cabezas: $cabezas, fechaAlta: $fechaAlta, fechaInicio: $fechaInicio, metaKilos: $metaKilos, pesoInicio: $pesoInicio, pesoPromedio: $pesoPromedio, seguir: $seguir, vender: $vender, cpcAutomatico: $cpcAutomatico, cpc: $cpc, idDescarga: $idDescarga, primerDescarga: $primerDescarga, ultimaDescarga: $ultimaDescarga, ultimaFechaPesada: $ultimaFechaPesada, ultimaPesada: $ultimaPesada, ultimaLectura: $ultimaLectura, remanente: $remanente, incremento: $incremento, descargado: $descargado, decremento: $decremento, gdpv: $gdpv, materiaSeca: $materiaSeca, subtropa: $subtropa, tropaOrigen: $tropaOrigen, subtropasList: $subtropasList}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      super == other &&
          other is TropaEntity &&
          runtimeType == other.runtimeType &&
          uuid == other.uuid &&
          nombre == other.nombre &&
          categoriaUid == other.categoriaUid &&
          corralUid == other.corralUid &&
          activo == other.activo &&
          cerrado == other.cerrado &&
          pendiente == other.pendiente &&
          potreroUid == other.potreroUid &&
          propietario == other.propietario &&
          dieta == other.dieta &&
          caravana == other.caravana &&
          cabezas == other.cabezas &&
          fechaAlta == other.fechaAlta &&
          fechaInicio == other.fechaInicio &&
          metaKilos == other.metaKilos &&
          pesoInicio == other.pesoInicio &&
          pesoPromedio == other.pesoPromedio &&
          seguir == other.seguir &&
          vender == other.vender &&
          cpcAutomatico == other.cpcAutomatico &&
          cpc == other.cpc &&
          idDescarga == other.idDescarga &&
          primerDescarga == other.primerDescarga &&
          ultimaDescarga == other.ultimaDescarga &&
          ultimaFechaPesada == other.ultimaFechaPesada &&
          ultimaPesada == other.ultimaPesada &&
          ultimaLectura == other.ultimaLectura &&
          remanente == other.remanente &&
          incremento == other.incremento &&
          descargado == other.descargado &&
          decremento == other.decremento &&
          gdpv == other.gdpv &&
          materiaSeca == other.materiaSeca &&
          subtropa == other.subtropa &&
          tropaOrigen == other.tropaOrigen &&
          subtropasList == other.subtropasList;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      nombre.hashCode ^
      categoriaUid.hashCode ^
      corralUid.hashCode ^
      activo.hashCode ^
      cerrado.hashCode ^
      pendiente.hashCode ^
      potreroUid.hashCode ^
      propietario.hashCode ^
      dieta.hashCode ^
      caravana.hashCode ^
      cabezas.hashCode ^
      fechaAlta.hashCode ^
      fechaInicio.hashCode ^
      metaKilos.hashCode ^
      pesoInicio.hashCode ^
      pesoPromedio.hashCode ^
      seguir.hashCode ^
      vender.hashCode ^
      cpcAutomatico.hashCode ^
      cpc.hashCode ^
      idDescarga.hashCode ^
      primerDescarga.hashCode ^
      ultimaDescarga.hashCode ^
      ultimaFechaPesada.hashCode ^
      ultimaPesada.hashCode ^
      ultimaLectura.hashCode ^
      remanente.hashCode ^
      incremento.hashCode ^
      descargado.hashCode ^
      decremento.hashCode ^
      gdpv.hashCode ^
      materiaSeca.hashCode ^
      subtropa.hashCode ^
      tropaOrigen.hashCode ^
      subtropasList.hashCode;

  TropaEntity.fromJson(Map<String, Object> json)
      : uuid = json['uuid'],
        nombre = json['nombre'],
        categoriaUid = json['categoriaUid'],
        corralUid = json['corralUid'],
        activo = json['activo'],
        cerrado = json['cerrado'],
        pendiente = json['pendiente'],
        potreroUid = json['potreroUid'],
        propietario = json['propietario'],
        dieta = json['dieta'],
        caravana = json['caravana'],
        cabezas = json['cabezas'],
        fechaAlta = json['fechaAlta'],
        fechaInicio = json['fechaInicio'],
        metaKilos = json['metaKilos'],
        pesoInicio = json['pesoInicio'],
        pesoPromedio = json['pesoPromedio'],
        seguir = json['seguir'],
        vender = json['vender'],
        cpcAutomatico = json['cpcAutomatico'],
        cpc = json['cpc'],
        incremento = json['incremento'],
        decremento = json['decremento'],
        gdpv = json['gdpv'],
        materiaSeca = json['materiaSeca'],
        subtropa = json['subtropa'],
        tropaOrigen = json['tropaOrigen'],
        subtropasList = json['subtropasList'],
        idDescarga = json['idDescarga'],
        primerDescarga = json['primerDescarga'],
        ultimaDescarga = json['ultimaDescarga'],
        ultimaFechaPesada = json['ultimaFechaPesada'],
        ultimaPesada = json['ultimaPesada'],
        ultimaLectura = json['ultimaLectura'],
        remanente = json['remanente'],
        descargado = json['descargado'];

  TropaEntity.fromSnapshot(DocumentSnapshot snapshot)
      : uuid = snapshot.documentID,
        nombre = snapshot.data['nombre'],
        cabezas = snapshot.data['cabezas'],
        categoriaUid = snapshot.data['categoria'],
        corralUid = snapshot.data['corral'],
        activo = snapshot.data['activo'],
        cerrado = snapshot.data['cerrado'],
        pendiente = snapshot.data['pendiente'] ?? false,
        potreroUid = snapshot.data['potrero'],
        propietario = snapshot.data['propietario'],
        dieta = snapshot.data['dieta'],
        caravana = snapshot.data['caravana'],
        fechaAlta = snapshot.data['fechaAlta'].toDate(),
        fechaInicio = snapshot.data['fechaInicio'] is Timestamp
            ? snapshot.data['fechaInicio'].toDate()
            : snapshot.data['fechaInicio'],
        metaKilos = snapshot.data['metaKilos'] != null
            ? snapshot.data['metaKilos'].runtimeType == double
                ? snapshot.data['metaKilos']
                : double.parse(snapshot.data['metaKilos'].toString())
            : 0.0,
        pesoInicio = snapshot.data['pesoInicio'],
        pesoPromedio = snapshot.data['pesoPromedio'],
        seguir = snapshot.data['seguir'],
        vender = snapshot.data['vender'],
        cpcAutomatico = snapshot.data['cpcAutomatico'],
        cpc = snapshot.data['cpc'].runtimeType == int
            ? double.parse(snapshot.data['cpc'].toString())
            : snapshot.data['cpc'],
        incremento = double.parse(snapshot.data['incremento'].toString()),
        decremento = double.parse(snapshot.data['decremento'].toString()),
        gdpv = double.parse(snapshot.data['gdpv'].toString()),
        materiaSeca = double.parse(snapshot.data['materiaSeca'].toString()),
        subtropa = snapshot.data['subtropa'] ?? false,
        tropaOrigen = snapshot.data['tropaOrigen'] ?? "",
        subtropasList = snapshot.data['subtropasList'] == null
            ? List<dynamic>()
            : snapshot.data['subtropasList'],
        descargado = snapshot.data['descargado'] is int
            ? double.parse(snapshot.data['descargado'].toString())
            : snapshot.data['descargado'],
        remanente = snapshot.data['remanente'] is int
            ? double.parse(snapshot.data['remanente'].toString())
            : snapshot.data['remanente'],
        ultimaLectura = snapshot.data['ultima_lectura'] != null
            ? snapshot.data['ultima_lectura'].toDate()
            : snapshot.data['fechaAlta'].toDate(),
        ultimaPesada = snapshot.data['ultimaPesada'] != null
            ? double.parse(snapshot.data['ultimaPesada'].toString())
            : snapshot.data['pesoInicio'],
        ultimaFechaPesada = snapshot.data['ultimaFechaPesada'] != null
            ? snapshot.data['ultimaFechaPesada'].toDate()
            : snapshot.data['fechaAlta'].toDate(),
        ultimaDescarga = snapshot.data['ultimaDescarga'] != null
            ? (snapshot.data['ultimaDescarga'] is int ||
                    snapshot.data['ultimaDescarga'] is double)
                ? DateTime.fromMillisecondsSinceEpoch(
                    snapshot.data['ultimaDescarga'].round().toInt())
                : snapshot.data['ultimaDescarga'].toDate()
            : snapshot.data['fechaAlta'].toDate(),
        idDescarga = snapshot.data['idDescarga'],
        primerDescarga = snapshot.data['primerDescarga'] != null
            ? (snapshot.data['primerDescarga'] is int ||
                    snapshot.data['primerDescarga'] is double)
                ? DateTime.fromMillisecondsSinceEpoch(
                    snapshot.data['primerDescarga'].round().toInt())
                : snapshot.data['primerDescarga'].toDate()
            : null;

  Map<String, Object> toDocument() {
    return {
      'activo': this.activo,
      'nombre': this.nombre,
      'categoria': this.categoriaUid,
      'corral': this.corralUid,
      'activo': this.activo,
      'cerrado': this.cerrado,
      'pendiente': this.pendiente,
      'potrero': this.potreroUid,
      'propietario': this.propietario,
      'dieta': this.dieta,
      'caravana': this.caravana,
      'cabezas': this.cabezas,
      'fechaAlta': this.fechaAlta,
      'fechaInicio': this.fechaInicio,
      'metaKilos': this.metaKilos,
      'pesoInicio': this.pesoInicio,
      'pesoPromedio': this.pesoPromedio,
      'seguir': this.seguir,
      'vender': this.vender,
      'cpcAutomatico': this.cpcAutomatico,
      'cpc': this.cpc,
      'incremento': this.incremento,
      'decremento': this.decremento,
      'gdpv': this.gdpv,
      'materiaSeca': this.materiaSeca,
      'subtropa': this.subtropa,
      'tropaOrigen': this.tropaOrigen,
      'subtropasList': this.subtropasList,
      'descargado': this.descargado,
      'remanente': this.remanente,
      'ultima_lectura': this.ultimaLectura,
      'ultimaPesada': this.ultimaPesada,
      'ultimaFechaPesada': this.ultimaFechaPesada,
      'ultimaDescarga': this.ultimaDescarga is DateTime
          ? this.ultimaDescarga.millisecondsSinceEpoch
          : this.ultimaDescarga,
      'idDescarga': this.idDescarga,
      'primerDescarga': this.primerDescarga is DateTime
          ? this.primerDescarga.millisecondsSinceEpoch
          : this.primerDescarga
    };
  }
}
